histore package
===============

Subpackages
-----------

.. toctree::

   histore.archive
   histore.document

Submodules
----------

histore.util module
-------------------

.. automodule:: histore.util
   :members:
   :undoc-members:
   :show-inheritance:

histore.version module
----------------------

.. automodule:: histore.version
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: histore
   :members:
   :undoc-members:
   :show-inheritance:
